aboutsummaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
Diffstat (limited to 'include')
-rw-r--r--include/render/egl.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/include/render/egl.h b/include/render/egl.h
index 7d593f69..191293bf 100644
--- a/include/render/egl.h
+++ b/include/render/egl.h
@@ -11,10 +11,11 @@ struct wlr_egl_context {
};
/**
* Initializes an EGL context for the given platform and remote display.
* Will attempt to load all possibly required api functions.
*/
-struct wlr_egl *wlr_egl_create(EGLenum platform, void *remote_display);
+struct wlr_egl *wlr_egl_create_with_drm_fd(int drm_fd);
/**
* Frees all related EGL resources, makes the context not-current and
@@ -11,10 +11,11 @@ struct wlr_egl_context {
};
/**
- * Initializes an EGL context for the given platform and remote display.
- * Will attempt to load all possibly required api functions.
+ * Initializes an EGL context for the given DRM FD.
+ *
+ * Will attempt to load all possibly required API functions.
*/